==> haskell-readable-0.3.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-readable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 readable
version:              0.3.1
visibility:           public
id:                   readable-0.3.1-LwsmJydF9gxIWeKsJxAuOV
key:                  readable-0.3.1-LwsmJydF9gxIWeKsJxAuOV
license:              BSD-3-Clause
maintainer:           mightybyte@gmail.com
author:               Doug Beardsley
homepage:             https://github.com/mightybyte/readable
synopsis:             Reading from Text and ByteString
description:
    Provides a Readable type class for reading data types from ByteString and
    Text.  Also includes efficient implementations for common data types.

category:             Text
abi:                  41fca6b86501d2e9fd840e3118cb897c
exposed:              True
exposed-modules:      Data.Readable
import-dirs:          /usr/lib/ghc-8.8.3/site-local/readable-0.3.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/readable-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/readable-0.3.1
hs-libraries:         HSreadable-0.3.1-LwsmJydF9gxIWeKsJxAuOV
depends:              base-4.13.0.0 bytestring-0.10.10.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-readable/html/readable.haddock
haddock-html:         /usr/share/doc/haskell-readable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-readable-0.3.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-readable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 readable
version:              0.3.1
visibility:           public
id:                   readable-0.3.1-9XGRBmKgpC24XWfI7OqMey
key:                  readable-0.3.1-9XGRBmKgpC24XWfI7OqMey
license:              BSD-3-Clause
maintainer:           mightybyte@gmail.com
author:               Doug Beardsley
homepage:             https://github.com/mightybyte/readable
synopsis:             Reading from Text and ByteString
description:
    Provides a Readable type class for reading data types from ByteString and
    Text.  Also includes efficient implementations for common data types.

category:             Text
abi:                  aa2dc9cf1f324d39246fe3880f5e18fc
exposed:              True
exposed-modules:      Data.Readable
import-dirs:          /usr/lib/ghc-8.10.1/site-local/readable-0.3.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/readable-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/readable-0.3.1
hs-libraries:         HSreadable-0.3.1-9XGRBmKgpC24XWfI7OqMey
depends:              base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-readable/html/readable.haddock
haddock-html:         /usr/share/doc/haskell-readable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
